@@ -2,7 +2,13 @@
 
 __author__ = """James Irving"""
 __email__ = 'james.irving.phd@gmail.com'
-__version__ = '0.1.10'
+__version__ = '0.2.25'
 
 from .default import *
+
+from fsds import datasets,jmi,quick_refs
+
+
+# from fsds_100719 import datasets
+# from fsds_100719 import quick_refs
 # from .fsds import imports 
\ No newline at end of file
